@@ -7,7 +7,7 @@ use autodie;
 
 use Carp qw(confess);
 
-our $VERSION = '0.10';
+our $VERSION = '1.00.00';
 
 sub new {
   my $class = shift;
@@ -150,7 +150,7 @@ Text::Table::Read::RelationOn::Tiny - Read binary "relation on (over) a set" fro
 
 =head1 VERSION
 
-Version 0.10
+Version 1.00.00
 
 
 =head1 SYNOPSIS
@@ -449,6 +449,11 @@ L<https://cpanratings.perl.org/d/Text-Table-Read-RelationOn-Tiny>
 
 L<https://metacpan.org/release/Text-Table-Read-RelationOn-Tiny>
 
+=item * GitHub Repository
+
+L<https://github.com/AAHAZRED/perl-Text-Table-Read-RelationOn-Tiny>
+
+
 =back
 
 
